@@ -1,5 +1,6 @@
 package Perlanet::Simple;
 
+use 5.10.0;
 use strict;
 use warnings;
 
@@ -43,7 +44,7 @@ planet working out of the box.
 
 Perlanet::Simple takes the standard Perlanet module, and adds support for
 caching, OPML feed generation, and L<Template> rendering support. It will
-also attempt to clean each post using both L<HTML::Scrubber> and L<HTML::Tidy>.
+also attempt to clean each post using both L<HTML::Scrubber> and L<HTML::T5>.
 
 =head2 Configuration
 
@@ -72,6 +73,8 @@ around clean_html => sub {
   my $self = shift;
   my ($html) = @_;
 
+  warn __PACKAGE__, '::clean_html' if $ENV{PERLANET_DEBUG};
+
   # hack to remove a particularly nasty piece of blogspot HTML
   $html = $self->$orig($html);
   $html =~ s|<div align="justify"></div>||g;
